@@ -135,7 +135,8 @@ void Titraqform::setupPrefs(void)
         m_pPrefs->setString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
         m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLECDE);
         m_pPrefs->setString(TITRAQ_PREFVIEW, TITRAQ_DEFVIEW);
-        m_pPrefs->setNumber(TITRAQ_PREFSORT, TITRAQ_DEFSORT);
+        m_pPrefs->setNumber(TITRAQ_PREFSORTCOL, TITRAQ_DEFSORTCOL);
+        m_pPrefs->setBool(TITRAQ_PREFSORTDIR, TITRAQ_DEFSORTDIR);
         m_pPrefs->setString(TITRAQ_PREFREMOTELOG, TITRAQ_DEFREMOTELOG);
         m_pPrefs->setString(TITRAQ_PREFLOCALLOG, TITRAQ_DEFLOCALLOG);
         m_pPrefs->flush();  // Write the new conf file
@@ -560,6 +561,10 @@ void Titraqform::setupTable(void)
     m_pMaintable->horizontalHeader()->setClickEnabled(true); // Allow click signals
     m_pMaintable->horizontalHeader()->setTracking(false); // No continuous tracking
     m_pMaintable->setColumnStretchable(TITRAQ_IDXTAIL - 1, true);
+
+    // Allow for user determined data sorting and use saved values
+    m_pMaintable->setSortcol((int)m_pPrefs->getNumber(TITRAQ_PREFSORTCOL, TITRAQ_DEFSORTCOL));
+    m_pMaintable->setSortdir(m_pPrefs->getBool(TITRAQ_PREFSORTDIR, TITRAQ_DEFSORTDIR));
     m_pMaintable->setSorting(true);
 
     // Table header row
@@ -620,14 +625,14 @@ void Titraqform::setupEditlay(void)
         throw Genexcept("Main window status edit creation failed.");
     m_pStatusedit->setPixmap(QPixmap(s_kpcStatvoid_xpm));   // Placeholder
 
-    QToolTip::add(m_pStatusedit, trUtf8("Status Item"));
-    m_pEditlayout->addWidget(m_pStatusedit);  // Finally add the item status edit
 
     // Whatsthis info for the item status edit
     const char *kszStatustext = "The <em>item status</em> shows a green "
                                 "symbol for valid entries, a yellow symbol "
                                 "to warn, and a red symbol for flawed entries.";
     QWhatsThis::add(m_pStatusedit, kszStatustext);
+    QToolTip::add(m_pStatusedit, trUtf8("Status Indicator"));
+    m_pEditlayout->addWidget(m_pStatusedit);  // Finally add the item status edit
 
     // Make the line number edit
     m_pLineedit = new QLineEdit(m_pCenframe, "Lineno");
@@ -639,14 +644,14 @@ void Titraqform::setupEditlay(void)
     m_pLineedit->setReadOnly(true);
     m_pLineedit->setEnabled(false);
     m_pLineedit->setAlignment(Qt::AlignRight);
-    QToolTip::add(m_pLineedit, trUtf8("Line Number"));
-    m_pEditlayout->addWidget(m_pLineedit);  // Finally add the line number edit
 
     // Whatsthis info for the line number edit
     const char *kszLinenotext = "The <em>line number</em> helps identify "
                                 "an entry when a warning or error message "
                                 "appears.";
     QWhatsThis::add(m_pLineedit, kszLinenotext);
+    QToolTip::add(m_pLineedit, trUtf8("Line Number"));
+    m_pEditlayout->addWidget(m_pLineedit);  // Finally add the line number edit
 
     // Make the user edit
     m_pUseredit = new QLineEdit(m_pCenframe, "User");
@@ -657,14 +662,14 @@ void Titraqform::setupEditlay(void)
     m_pUseredit->setFrame(true);
     m_pUseredit->setReadOnly(false);
     m_pUseredit->setEnabled(false);
-    QToolTip::add(m_pUseredit, trUtf8("User Name"));
-    m_pEditlayout->addWidget(m_pUseredit);  // Finally add the user edit
 
     // Whatsthis info for the user edit
     const char *kszUsertext = "Edit the <em>user name</em> by clicking "
                               "on this control and typing the user name "
                               "you want to account.";
     QWhatsThis::add(m_pUseredit, kszUsertext);
+    QToolTip::add(m_pUseredit, trUtf8("User Name"));
+    m_pEditlayout->addWidget(m_pUseredit);  // Finally add the user edit
 
     // Make the GUID edit
     m_pGuidedit = new QLineEdit(m_pCenframe, "Guid");
@@ -675,14 +680,14 @@ void Titraqform::setupEditlay(void)
     m_pGuidedit->setFrame(true);
     m_pGuidedit->setReadOnly(true);
     m_pGuidedit->setEnabled(false);
-    QToolTip::add(m_pGuidedit, trUtf8("GUID"));
-    m_pEditlayout->addWidget(m_pGuidedit);  // Finally add the GUID edit
 
     // Whatsthis info for the GUID edit
     const char *kszGuidtext = "Edit the <em>GUID</em> by clicking "
                               "on this control and typing the GUID "
                               "corresponding to this account item.";
     QWhatsThis::add(m_pGuidedit, kszGuidtext);
+    QToolTip::add(m_pGuidedit, trUtf8("GUID"));
+    m_pEditlayout->addWidget(m_pGuidedit);  // Finally add the GUID edit
 
     // Make the CRC edit
     m_pCrcedit = new QLineEdit(m_pCenframe, "Crc");
@@ -693,14 +698,14 @@ void Titraqform::setupEditlay(void)
     m_pCrcedit->setFrame(true);
     m_pCrcedit->setReadOnly(true);
     m_pCrcedit->setEnabled(false);
-    QToolTip::add(m_pCrcedit, trUtf8("CRC"));
-    m_pEditlayout->addWidget(m_pCrcedit);  // Finally add the CRC edit
 
     // Whatsthis info for the CRC edit
     const char *kszCrctext = "Edit the <em>CRC</em> by clicking "
                              "on this control and typing the new "
                              "value for this account item.";
     QWhatsThis::add(m_pCrcedit, kszCrctext);
+    QToolTip::add(m_pCrcedit, trUtf8("CRC"));
+    m_pEditlayout->addWidget(m_pCrcedit);  // Finally add the CRC edit
 
     // Make the revision edit
     m_pRevedit = new QLineEdit(m_pCenframe, "Revision");
@@ -711,14 +716,14 @@ void Titraqform::setupEditlay(void)
     m_pRevedit->setFrame(true);
     m_pRevedit->setReadOnly(true);
     m_pRevedit->setEnabled(false);
-    QToolTip::add(m_pRevedit, trUtf8("Revision"));
-    m_pEditlayout->addWidget(m_pRevedit);  // Finally add the revision edit
 
     // Whatsthis info for the revision edit
     const char *kszRevtext = "Edit the <em>revision</em> by clicking "
                              "on this control and typing the new value "
                              "for this account type.";
     QWhatsThis::add(m_pRevedit, kszRevtext);
+    QToolTip::add(m_pRevedit, trUtf8("Revision"));
+    m_pEditlayout->addWidget(m_pRevedit);  // Finally add the revision edit
 
     // Make the date selector
     m_pDateedit = new QDateEdit(m_pCenframe, "Date");
@@ -732,14 +737,13 @@ void Titraqform::setupEditlay(void)
     m_pDateedit->setSeparator(trUtf8("."));
     m_pDateedit->setEnabled(false);
 
-    m_pEditlayout->addWidget(m_pDateedit);                          // Finally add the date editor
-    QToolTip::add(m_pDateedit, trUtf8("Task Date"));
-
     // Whatsthis info for the date editor
     const char *kszDateedit = "Edit the <em>task date</em> by clicking on "
                               "the year, month, or day, and then changing their "
                               "values with the arrow buttons.";
     QWhatsThis::add(m_pDateedit, kszDateedit);
+    QToolTip::add(m_pDateedit, trUtf8("Task Date"));
+    m_pEditlayout->addWidget(m_pDateedit);                          // Finally add the date editor
 
     // Make the start time selector
     m_pStarttime = new QTimeEdit(m_pCenframe, "StartTime");
@@ -751,14 +755,13 @@ void Titraqform::setupEditlay(void)
     m_pStarttime->setAutoAdvance(true);
     m_pStarttime->setEnabled(false);
 
-    m_pEditlayout->addWidget(m_pStarttime);                         // Finally add the start editor
-    QToolTip::add(m_pStarttime, trUtf8("Task Starting Time"));
-
     // Whatsthis info for the time editor
     const char *kszStarttime = "Edit the <em>task starting time</em> by clicking on "
                                "the hour and minute, and then changing their "
                                "values with the arrow buttons.";
     QWhatsThis::add(m_pStarttime, kszStarttime);
+    QToolTip::add(m_pStarttime, trUtf8("Task Starting Time"));
+    m_pEditlayout->addWidget(m_pStarttime);                         // Finally add the start editor
 
     // Make the end time selector
     m_pEndtime = new QTimeEdit(m_pCenframe, "EndTime");
@@ -770,14 +773,13 @@ void Titraqform::setupEditlay(void)
     m_pEndtime->setAutoAdvance(true);
     m_pEndtime->setEnabled(false);
 
-    m_pEditlayout->addWidget(m_pEndtime);                           // Finally add the end editor
-    QToolTip::add(m_pEndtime, trUtf8("Task Ending Time"));
-
     // Whatsthis info for the time editor
     const char *kszEndtime = "Edit the <em>task ending time</em> by clicking on "
                              "the hour and minute, and then changing their "
                              "values with the arrow buttons.";
     QWhatsThis::add(m_pEndtime, kszEndtime);
+    QToolTip::add(m_pEndtime, trUtf8("Task Ending Time"));
+    m_pEditlayout->addWidget(m_pEndtime);                           // Finally add the end editor
 
     // Make the amount selector
     m_pAmount = new AmountBox(TITRAQ_MINAMOUNT, TITRAQ_MAXAMOUNT, TITRAQ_STEPAMOUNT, m_pCenframe, "Amount");
@@ -790,14 +792,13 @@ void Titraqform::setupEditlay(void)
     m_pAmount->setEnabled(false);
 //    m_pAmount->setSpecialValueText(trUtf8("In progress"));
 
-    m_pEditlayout->addWidget(m_pAmount);    // Finally add the amount editor
-    QToolTip::add(m_pAmount, trUtf8("Task Amount"));
-
     // Whatsthis info for the amount editor
     const char *kszAmount = "Edit the <em>task amount</em> by clicking on "
                             "the amount, and then changing its "
                             "value with the arrow buttons.";
     QWhatsThis::add(m_pAmount, kszAmount);
+    QToolTip::add(m_pAmount, trUtf8("Task Amount"));
+    m_pEditlayout->addWidget(m_pAmount);    // Finally add the amount editor
 
     // Construct a stringlist just to hold task values
     m_pTaskentries = new QStringList;
@@ -828,6 +829,8 @@ void Titraqform::setupEditlay(void)
     const char *kszTasktext = "Choose a <em>task account</em> by clicking on "
                               "this box, and choosing whichever item most "
                               "closely resembles your task.";
+    QWhatsThis::add(m_pTasks, kszTasktext);
+    QToolTip::add(m_pTasks, trUtf8("Task Selector"));
     m_pEditlayout->addWidget(m_pTasks); // Finally add the task edit
 
     // Make the Remark line
@@ -839,14 +842,14 @@ void Titraqform::setupEditlay(void)
     m_pRemark->setFrame(true);
     m_pRemark->setReadOnly(false);
     m_pRemark->setEnabled(false);
-    QToolTip::add(m_pRemark, trUtf8("Remark Line"));
-    m_pEditlayout->addWidget(m_pRemark);    // Finally add the remark line
 
     // Whatsthis info for the remark line
     const char *kszRemarktext = "Edit the <em>task remarks</em> by clicking on "
                                 "this line control and typing the remarks you "
                                 "have about the task.";
     QWhatsThis::add(m_pRemark, kszRemarktext);
+    QToolTip::add(m_pRemark, trUtf8("Remark Line"));
+    m_pEditlayout->addWidget(m_pRemark);    // Finally add the remark line
 
     // Start edit controls off at right size
     this->updSizes(TITRAQ_IDXALLCTRLS, -1, -1);
@@ -920,6 +923,7 @@ void Titraqform::setupColumns(void)
 //
 void Titraqform::enableIface(bool bTurned)
 {
+    // FIXME: Does not belong here, so relocate
     if (!bTurned)
         m_pMaintable->setNumRows(0);    // Remove table data
 
@@ -949,6 +953,6 @@ void Titraqform::enableIface(bool bTurned)
     m_pPasteact->setEnabled(bTurned);
 
     // Unconditional settings
-    this->updEdit(0, 0);            // Update edit controls
-    m_pMaintable->setDirty(false);  // Reset to clean data
+    this->updEdit(m_pMaintable->currentRow(), 0);   // Update edit controls
+    m_pMaintable->setDirty(false);                  // Reset to clean data
 }
