@@ -262,14 +262,7 @@ void Titraqform::newDoc(void)
     this->setCaption(trUtf8("No file name"));
     m_pStatbar->message(trUtf8("New document"), 4000);
     this->setFilename("");
-
-    // Reset widget text of edit controls
-    m_pDateedit->setDate(*m_pDatezero);
-    m_pStarttime->setTime(QTime::QTime(0, 0));
-    m_pEndtime->setTime(QTime::QTime(0, 0));
-    m_pAmount->setText(NULL);
-    m_pTasks->setCurrentText(NULL);
-    m_pRemark->setText(NULL);
+    this->updEdit(0, 0);                // Update edit controls
 }
 
 //
@@ -1194,8 +1187,9 @@ void Titraqform::savePrefs(void)
     if (m_pMaintable->columnWidth(TITRAQ_IDXREMARK) > 0)
         m_pPrefs->setNumber(TITRAQ_PREFREMCOLWIDTH, (long)m_pMaintable->columnWidth(TITRAQ_IDXREMARK));
 
-    // Get sorting order from matrix table and pass it to prefs handler
-    m_pPrefs->setNumber(TITRAQ_PREFSORT, (long)m_pMaintable->getSortcol());
+    // Get sorting order and direction from table and pass it to prefs handler
+    m_pPrefs->setNumber(TITRAQ_PREFSORTCOL, (long)m_pMaintable->getSortcol());
+    m_pPrefs->setBool(TITRAQ_PREFSORTDIR, (long)m_pMaintable->getSortdir());
 
     // Set frame geometry preferences
     m_pPrefs->setNumber(TITRAQ_PREFFRAMEWIDTH, (long)this->width());
